Class: Fog::Google::Storage::Real

Inherits:
Object
  • Object
show all
Defined in:
lib/fog/google/requests/storage/get_bucket_acl.rb

Instance Method Summary collapse

Instance Method Details

#get_bucket_acl(bucket_name) ⇒ Object

Get access control list for an Google Storage bucket

Parameters

  • bucket_name<~String> - name of bucket to get access control list for

Returns

  • response<~Excon::Response>:
    • body<~Hash>:
      • 'AccessControlPolicy'<~Hash>
        • 'Owner'<~Hash>:
          • 'DisplayName'<~String> - Display name of object owner
          • 'ID'<~String> - Id of object owner
        • 'AccessControlList'<~Array>:
          • 'Grant'<~Hash>:
            • 'Grantee'<~Hash>:
              • 'DisplayName'<~String> - Display name of grantee
              • 'ID'<~String> - Id of grantee or
              • 'URI'<~String> - URI of group to grant access for
            • 'Permission'<~String> - Permission, in [FULL_CONTROL, WRITE, WRITE_ACP, READ, READ_ACP]


29
30
31
32
33
34
35
36
37
38
39
40
41
42
# File 'lib/fog/google/requests/storage/get_bucket_acl.rb', line 29

def get_bucket_acl(bucket_name)
  unless bucket_name
    raise ArgumentError.new('bucket_name is required')
  end
  request({
    :expects    => 200,
    :headers    => {},
    :host       => "#{bucket_name}.#{@host}",
    :idempotent => true,
    :method     => 'GET',
    :parser     => Fog::Parsers::Storage::Google::AccessControlList.new,
    :query      => {'acl' => nil}
  })
end